==> monaco-vscode-debug-service-override-8.0.4.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugAccessibilityAnnouncer.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug.service';
import { Disposable, MutableDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { ILogService } from 'vscode/vscode/vs/platform/log/common/log.service';
import { IAccessibilityService } from 'vscode/vscode/vs/platform/accessibility/common/accessibility.service';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';

let DebugWatchAccessibilityAnnouncer = class DebugWatchAccessibilityAnnouncer extends Disposable {
    static { this.ID = 'workbench.contrib.debugWatchAccessibilityAnnouncer'; }
    constructor(_debugService, _logService, _accessibilityService, _configurationService) {
        super();
        this._debugService = _debugService;
        this._logService = _logService;
        this._accessibilityService = _accessibilityService;
        this._configurationService = _configurationService;
        this._listener = this._register(( new MutableDisposable()));
        this._setListener();
        this._register(_configurationService.onDidChangeConfiguration(e => {
            if (e.affectsConfiguration('accessibility.debugWatchVariableAnnouncements')) {
                this._setListener();
            }
        }));
    }
    _setListener() {
        const value = this._configurationService.getValue('accessibility.debugWatchVariableAnnouncements');
        if (value && !this._listener.value) {
            this._listener.value = this._debugService.getModel().onDidChangeWatchExpressionValue((e) => {
                if (!e || e.value === 'not available') {
                    return;
                }
                this._accessibilityService.alert(`${e.name} = ${e.value}`);
                this._logService.trace(`debugAccessibilityAnnouncerValueChanged ${e.name} ${e.value}`);
            });
        }
        else {
            this._listener.clear();
        }
    }
};
DebugWatchAccessibilityAnnouncer = ( __decorate([
    ( __param(0, IDebugService)),
    ( __param(1, ILogService)),
    ( __param(2, IAccessibilityService)),
    ( __param(3, IConfigurationService))
], DebugWatchAccessibilityAnnouncer));

export { DebugWatchAccessibilityAnnouncer };

==> monaco-vscode-debug-service-override-9.0.2.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugAccessibilityAnnouncer.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug.service';
import { Disposable, MutableDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { ILogService } from 'vscode/vscode/vs/platform/log/common/log.service';
import { IAccessibilityService } from 'vscode/vscode/vs/platform/accessibility/common/accessibility.service';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';
import { Expression } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugModel';

let DebugWatchAccessibilityAnnouncer = class DebugWatchAccessibilityAnnouncer extends Disposable {
    static { this.ID = 'workbench.contrib.debugWatchAccessibilityAnnouncer'; }
    constructor(_debugService, _logService, _accessibilityService, _configurationService) {
        super();
        this._debugService = _debugService;
        this._logService = _logService;
        this._accessibilityService = _accessibilityService;
        this._configurationService = _configurationService;
        this._listener = this._register(( new MutableDisposable()));
        this._setListener();
        this._register(_configurationService.onDidChangeConfiguration(e => {
            if (e.affectsConfiguration('accessibility.debugWatchVariableAnnouncements')) {
                this._setListener();
            }
        }));
    }
    _setListener() {
        const value = this._configurationService.getValue('accessibility.debugWatchVariableAnnouncements');
        if (value && !this._listener.value) {
            this._listener.value = this._debugService.getModel().onDidChangeWatchExpressionValue((e) => {
                if (!e || e.value === Expression.DEFAULT_VALUE) {
                    return;
                }
                this._accessibilityService.alert(`${e.name} = ${e.value}`);
                this._logService.trace(`debugAccessibilityAnnouncerValueChanged ${e.name} ${e.value}`);
            });
        }
        else {
            this._listener.clear();
        }
    }
};
DebugWatchAccessibilityAnnouncer = ( __decorate([
    ( __param(0, IDebugService)),
    ( __param(1, ILogService)),
    ( __param(2, IAccessibilityService)),
    ( __param(3, IConfigurationService))
], DebugWatchAccessibilityAnnouncer));

export { DebugWatchAccessibilityAnnouncer };
